;; Generated package description from gnosis.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "gnosis" "0.10.6.0.20260707.26" "Knowledge System" '((emacs "29.1") (compat "29.1.4.2") (keymap-popup "0.2.0")) :commit "f68bfc5500c38c1edb59ea6eed70b7a765d368f0" :authors '(("Thanos Apollo" . "public@thanosapollo.org")) :maintainer '("Thanos Apollo" . "public@thanosapollo.org") :keywords '("extensions") :url "https://codeberg.org/thanosapollo/emacs-gnosis")
